@@ -30,8 +30,10 @@ WAIT_FOR_SPLIT = 1 / 256
 SGR_RE = re.compile(r'\x1b\[[0-9;]*m')
 
 # Sequences upon which ct will split during processing. This includes new lines,
-# vertical spaces, form feeds, C1 set (ECMA-048), CSI (excluding SGR), and OSC.
+# vertical spaces, form feeds, C1 set (ECMA-048), SCS (G0 through G3 sets),
+# CSI (excluding SGR), and OSC.
 SPLIT_RE = re.compile(r'(\r\n?|\n|\v|\f|\x1b[\x40-\x5a\x5c\x5e\x5f]|'
+                      r'\x1b[\x28-\x2b\x2d-\x2f][\x20-\x7e]|'
                       r'\x1b\x5b[\x30-\x3f]*[\x20-\x2f]*[\x40-\x6c\x6e-\x7e]|'
                       r'\x1b\x5d[\x08-\x0d\x20-\x7e]*(?:\x07|\x1b\x5c))')
 
@@ -305,12 +307,9 @@ def process_input(config, data_fd, forward_fd=None, max_wait=None):
         max_wait (float): The maximum time to wait with no data on either of the
             file descriptors. None will block until at least one ready to be read.
     """
-    if forward_fd is None:
-        fds = [data_fd]
-    else:
-        fds = [data_fd, forward_fd]
-
+    fds = [data_fd] if forward_fd is None else [data_fd, forward_fd]
     buffer = ''
+
     ready_fds = read_ready(*fds, timeout=max_wait)
 
     while ready_fds:
@@ -319,17 +318,17 @@ def process_input(config, data_fd, forward_fd=None, max_wait=None):
             try:
                 os.write(data_fd, os.read(forward_fd, READ_SIZE))
             except OSError:
-                # spawned program or stdin closed; don't forward anymore
+                # Spawned program or stdin closed; don't forward anymore
                 fds.remove(forward_fd)
 
         # Data to be highlighted was received
         if data_fd in ready_fds:
             try:
-                data = os.read(data_fd, READ_SIZE)
+                data_read = os.read(data_fd, READ_SIZE)
             except OSError:
-                data = b''
+                data_read = b''
 
-            buffer += data.decode(encoding='utf-8', errors='replace')
+            buffer += data_read.decode(encoding='utf-8', errors='replace')
 
             # Buffer was processed empty and data fd hit EOF
             if not buffer:
@@ -337,27 +336,27 @@ def process_input(config, data_fd, forward_fd=None, max_wait=None):
 
             splits = split_buffer(buffer)
 
-            # Process all splits except for the last as might've been cut off
+            # Process splits except for the last one as it might've been cut off
             for data, separator in splits[:-1]:
                 sys.stdout.write(config.highlight(data) + separator)
 
             # Data was read and there's more to come; wait before highlighting
-            if data and read_ready(data_fd, timeout=WAIT_FOR_SPLIT):
+            if data_read and read_ready(data_fd, timeout=WAIT_FOR_SPLIT):
                 buffer = splits[-1][0] + splits[-1][1]
-                continue
-
-            # A single character would indicate keyboard typing; don't highlight
-            if len(splits[-1][0]) == 1:
-                leftover_data = splits[-1][0]
+            # No data buffered; print last split
             else:
-                leftover_data = config.highlight(splits[-1][0])
+                # A single character indicates keyboard typing; don't highlight
+                if len(splits[-1][0]) == 1:
+                    leftover_data = splits[-1][0]
+                else:
+                    leftover_data = config.highlight(splits[-1][0])
 
-            # No more data; print last split and flush (doesn't have a new line)
-            sys.stdout.write(leftover_data + splits[-1][1])
+                sys.stdout.write(leftover_data + splits[-1][1])
+                buffer = ''
+
+            # Flush as the last split might not end with a new line
             sys.stdout.flush()
 
-            buffer = ''
-
         ready_fds = read_ready(*fds, timeout=max_wait)
 
 
@@ -491,15 +490,13 @@ def split_buffer(buffer):
     return tuple(zip(splits[0::2], splits[1::2]))
 
 
-def main(args=None, max_wait=None, stdin_fd=None, write_default=True):
+def main(args=None, max_wait=None, write_default=True):
     """Command line utility entry point.
 
     Args:
         args (list): A list of program arguments. Defaults to sys.argv.
         max_wait (float): The maximum time to wait with no data. None will block
             until data is ready to be read.
-        stdin_fd (int): The file descriptor considered as stdin. None will default
-            to sys.stdin.fileno().
         write_default (bool): Whether to write the default configuration or not.
             Only written if it doesn't exist already.
 
@@ -529,10 +526,10 @@ def main(args=None, max_wait=None, stdin_fd=None, write_default=True):
         # ChromaTerm is spawning the program in a controlling terminal; stdin is
         # being forwarded to the program
         data_fd = run_program([args.program] + args.arguments)
-        forward_fd = sys.stdin.fileno() if stdin_fd is None else stdin_fd
+        forward_fd = sys.stdin.fileno()
     else:
         # Data is being piped into ChromaTerm's stdin; no forwarding needed
-        data_fd = sys.stdin.fileno() if stdin_fd is None else stdin_fd
+        data_fd = sys.stdin.fileno()
         forward_fd = None
 
     # Ignore SIGPIPE (broken pipe) and SIGINT (CTRL+C), and attach reload handler
